==> speech-analytic-testing_3.5.4_database.tar.gz: database/mssql/procedures/SaveSentimentAnalysisResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveSentimentAnalysisResult] (
	@VCC varchar(50),
	@InteractionId varchar(250),
	@InteractionSection numeric(5,0),
	@InteractionPart numeric(5,0),
	@InteractionType varchar(50),
	@InteractionInterval numeric(5,0),
	@AnalysisType varchar(50),
	@SentimentId varchar(50),
	@AppId varchar(50),
	@Score numeric(10,5),
	@CreatedDate datetime,
	@CreatedByUserId varchar(50),
	@LastModifiedDate datetime,
	@LastModifiedByUserId varchar(50),
	@EndDate varchar(50)
	)
AS
BEGIN
	SET NOCOUNT ON
	UPDATE [SentimentAnalysisResult]
	SET [VCC] = @VCC,
		[InteractionId] = @InteractionId,
		[InteractionSection] = @InteractionSection,
		[InteractionPart] = @InteractionPart,
		[InteractionType] = @InteractionType,
		[InteractionInterval] = @InteractionInterval,
		[AnalysisType] = @AnalysisType,
		[SentimentId] = @SentimentId,
		[AppId] = @AppId,
		[Score] = @Score,		
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = GETUTCDATE(),
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE(),
		[EndDate] = @EndDate
		
	WHERE [VCC] = @VCC
    AND [InteractionId] = @InteractionId
	AND [InteractionSection] = @InteractionSection
	AND	[InteractionPart] = @InteractionPart
	AND [InteractionType] = @InteractionType
	AND [InteractionInterval] = @InteractionPart
	AND [AnalysisType] = @AnalysisType
	AND [SentimentId] = @SentimentId
	AND [AppId] = @AppId
	AND [EndDate] = @EndDate
	

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [SentimentAnalysisResult] (
			[VCC], 
			[InteractionId],
			[InteractionSection],
			[InteractionPart],
			[InteractionType],
			[InteractionInterval],
			[AnalysisType],
			[SentimentId],
			[AppId],
			[Score],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp],
			[EndDate]

			)
		VALUES (
			@VCC,
			@InteractionId,
			@InteractionSection,
			@InteractionPart,
			@InteractionType,
			@InteractionInterval,
			@AnalysisType,
			@SentimentId,
			@AppId,
			@Score,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@LastModifiedByUserId,
			GETUTCDATE(),
			@EndDate
		)
	END
	
	

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.5.6_database.tar.gz: database/mssql/procedures/SaveSentimentAnalysisResult.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveSentimentAnalysisResult] (
	@VCC varchar(50),
	@InteractionId varchar(250),
	@InteractionSection numeric(5,0),
	@InteractionPart numeric(5,0),
	@InteractionType varchar(50),
	@InteractionInterval numeric(5,0),
	@AnalysisType varchar(50),
	@SentimentId varchar(50),
	@AppId varchar(50),
	@Score numeric(10,5),
	@CreatedDate datetime,
	@CreatedByUserId varchar(50),
	@LastModifiedDate datetime,
	@LastModifiedByUserId varchar(50),
	@EndDate varchar(50),
    @Status varchar(50)
	)
AS
BEGIN
	SET NOCOUNT ON
	UPDATE [SentimentAnalysisResult]
	SET [VCC] = @VCC,
		[InteractionId] = @InteractionId,
		[InteractionSection] = @InteractionSection,
		[InteractionPart] = @InteractionPart,
		[InteractionType] = @InteractionType,
		[InteractionInterval] = @InteractionInterval,
		[AnalysisType] = @AnalysisType,
		[SentimentId] = @SentimentId,
		[AppId] = @AppId,
		[Score] = @Score,		
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = GETUTCDATE(),
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE(),
		[EndDate] = CASE WHEN @InteractionType = 'CALL' THEN '' ELSE  @EndDate END, 
        [MaxScore] = CASE WHEN @Status = 'Normal' THEN 0 ELSE 1 END
		
	WHERE [VCC] = @VCC
    AND [InteractionId] = @InteractionId
	AND [InteractionSection] = @InteractionSection
	AND	[InteractionPart] = @InteractionPart
	AND [InteractionType] = @InteractionType
	AND [InteractionInterval] = @InteractionPart
	AND [AnalysisType] = @AnalysisType
	AND [SentimentId] = @SentimentId
	AND [AppId] = @AppId
	AND [EndDate] = @EndDate
	

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [SentimentAnalysisResult] (
			[VCC], 
			[InteractionId],
			[InteractionSection],
			[InteractionPart],
			[InteractionType],
			[InteractionInterval],
			[AnalysisType],
			[SentimentId],
			[AppId],
			[Score],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp],
			[EndDate],
            [MaxScore]

			)
		VALUES (
			@VCC,
			@InteractionId,
			@InteractionSection,
			@InteractionPart,
			@InteractionType,
			@InteractionInterval,
			@AnalysisType,
			@SentimentId,
			@AppId,
			@Score,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@LastModifiedByUserId,
			GETUTCDATE(),
			CASE WHEN @InteractionType = 'CALL' THEN '' ELSE  @EndDate END,
            CASE WHEN @Status = 'Normal' THEN 0 ELSE 1 END
		)
	END
	
	

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
